@@ -16,6 +16,12 @@ options = (
         'help': 'Add a temporary suffix to S3 keys during transaction',
         'group': 's3',
         'level': 2}),
+    ('s3-activate-object-versioning', {
+        'type': 'yn',
+        'default': False,
+        'help': 'store the objects version-id in database',
+        'group': 's3',
+        'level': 2}),
 )
 
 
